From mboxrd@z Thu Jan  1 00:00:00 1970
From: Klemens Nanni <klemens@posteo.de>
To: list+catgirl@causal.agency
Cc: Klemens Nanni <klemens@posteo.de>
Subject: [PATCH] nick/channel colors: Use reverse video not colors for topic change when disabled
Date: Sun, 23 May 2021 17:26:19 +0000
Message-Id: <20210523172620.54723-2-klemens@posteo.de>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

`-H 0,0`/"hash = 0,0" makes catgirl mostly colorless which is great,
but topic changes still hardcode brown/green colors to show differences
which is usually not desired by users (like me) disabling colors.

Go for a less eye stressing topic change message that shows both old
and new in reverse video with default terminal colors.

This isn't perfect, other parts of catgirl still hardcode colors and
`-H 0,0`/"hash = 0,0" was never meant to disable colors completely, but
topics change often enough that avoiding less readable^Waccessible topic
diffs seems sensible enough.

NB: parseHash() is brittle and "0,0" is not the only value disabling
colors...
---
 chat.h   | 3 +++
 handle.c | 5 +++++
 2 files changed, 8 insertions(+)

diff --git a/chat.h b/chat.h
index fadbc30..57fdc62 100644
--- a/chat.h
+++ b/chat.h
@@ -138,6 +138,9 @@ static inline uint idFor(const char *name) {
 
 extern uint32_t hashInit;
 extern uint32_t hashBound;
+static inline bool colorDisabled(void) {
+	return hashInit == 0 && hashBound == 0;
+}
 static inline enum Color hash(const char *str) {
 	if (hashBound < Blue) return Default;
 	if (*str == '~') str++;
diff --git a/handle.c b/handle.c
index 09b28d5..d210aac 100644
--- a/handle.c
+++ b/handle.c
@@ -662,6 +662,11 @@ static void handleTopic(struct Message *msg) {
 	if (swprintf(old, ARRAY_LEN(old), L"%s", prev) < 0) goto plain;
 	if (swprintf(new, ARRAY_LEN(new), L"%s", msg->params[1]) < 0) goto plain;
 
+	if (colorDisabled()) {
+		catf(&cat, "\3%c%ls%c -> %c%ls%c", R, old, R, R, new, R);
+		goto plain;
+	}
+
 	size_t pre;
 	for (pre = 0; old[pre] && new[pre] && old[pre] == new[pre]; ++pre);
 	wchar_t *osuf = &old[wcslen(old)];
-- 
2.31.1


From mboxrd@z Thu Jan  1 00:00:00 1970
Content-Type: text/plain;
	charset=utf-8
Mime-Version: 1.0 (Mac OS X Mail 13.4 \(3608.120.23.2.6\))
Subject: Re: [PATCH] nick/channel colors: Use reverse video not colors for
 topic change when disabled
From: june <june@causal.agency>
In-Reply-To: <20210523172620.54723-2-klemens@posteo.de>
Date: Tue, 25 May 2021 16:29:48 -0400
Cc: list+catgirl@causal.agency
Content-Transfer-Encoding: quoted-printable
Message-Id: <A15BF5B7-7592-487F-9206-982E6DFB6ECE@causal.agency>
References: <20210523172620.54723-2-klemens@posteo.de>
To: Klemens Nanni <klemens@posteo.de>

Thanks, applied. Replaced some R=E2=80=99s with O=E2=80=99s to reset any =
formatting
that might be in the topics.


From mboxrd@z Thu Jan  1 00:00:00 1970
Date: Tue, 25 May 2021 21:11:03 +0000
From: Klemens Nanni <klemens@posteo.de>
To: june <june@causal.agency>
Cc: list+catgirl@causal.agency
Subject: Re: [PATCH] nick/channel colors: Use reverse video not colors for
 topic change when disabled
Message-ID: <YK1n5+uoSzMGFIS1@eru>
References: <20210523172620.54723-2-klemens@posteo.de>
 <A15BF5B7-7592-487F-9206-982E6DFB6ECE@causal.agency>
MIME-Version: 1.0
Content-Type: text/plain; charset=utf-8
Content-Disposition: inline
Content-Transfer-Encoding: 8bit
In-Reply-To: <A15BF5B7-7592-487F-9206-982E6DFB6ECE@causal.agency>

On Tue, May 25, 2021 at 04:29:48PM -0400, june wrote:
> Thanks, applied. Replaced some R’s with O’s to reset any formatting
> that might be in the topics.
Right, R wouldn't suffice; thanks.

